.. py:currentmodule:: pydlm
		      
Class Reference
===============

:class:`dlm`
------------

.. autoclass:: pydlm.dlm
    :members:

:class:`trend`
--------------

.. autoclass:: pydlm.trend
    :members:

:class:`seasonality`
--------------------

.. autoclass:: pydlm.seasonality
    :members:

:class:`dynamic`
----------------

.. autoclass:: pydlm.dynamic
    :members:


:class:`autoReg`
----------------

.. autoclass:: pydlm.autoReg
    :members:

:class:`longSeason`
-------------------

.. autoclass:: pydlm.longSeason
    :members:

:class:`modelTuner`
-------------------

.. autoclass:: pydlm.modelTuner
    :members:
